@@ -5,15 +5,13 @@ footprints = {
     'cubieboard2': Footprint('Cubian', cpu_count=2, mem_size=847970304),
     'cubietruck': Footprint('Cubian', cpu_count=2, mem_size=1911201792),
     'raspberrypi': Footprint('raspberrypi'),
-    'beagleboneblack': Footprint('arm'),
-    'my_PC': Footprint('XPS13', mem_size=7873978368, cpu_count=4)
+    'beagleboneblack': Footprint('arm')
 }
 
 titles = {
     'cubieboard': 'Cubieboard',
     'cubieboard2': 'Cubieboard2',
     'cubietruck': 'Cubietruck',
-    'raspberrypi': 'Raspberry Pi',
-    'beagleboneblack': 'BeagleBone Black',
-    'my_PC': 'My awesome PC'
+    'raspberrypi': 'Raspberry Pi Model B',
+    'beagleboneblack': 'BeagleBone Black'
 }
\ No newline at end of file
